Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(554)

Unified Diff: pkg/compiler/lib/src/serialization/element_serialization.dart

Issue 2603263002: Prefix resolution_types with Resolution. (Closed)
Patch Set: Rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/serialization/element_serialization.dart
diff --git a/pkg/compiler/lib/src/serialization/element_serialization.dart b/pkg/compiler/lib/src/serialization/element_serialization.dart
index c12fb4c1e633274d5b2096723701bdb2ed78a196..743952ec07d050d82b8cc57c6e1c013a6876c785 100644
--- a/pkg/compiler/lib/src/serialization/element_serialization.dart
+++ b/pkg/compiler/lib/src/serialization/element_serialization.dart
@@ -71,9 +71,9 @@ enum SerializedElementKind {
/// encoding into them into [ObjectEncoder]s.
///
/// This class is called from the [Serializer] when an [Element] needs
/// serialization. The [ObjectEncoder] ensures that any [Element], [DartType],
/// and [ConstantExpression] that the serialized [Element] depends upon are also
/// serialized.
const List<ElementSerializer> ELEMENT_SERIALIZERS = const [
const ErrorSerializer(),
const LibrarySerializer(),
@@ -179,7 +179,7 @@ class SerializerUtil {
/// Serialize the parameters of [element] into [encoder].
static void serializeParameters(
FunctionElement element, ObjectEncoder encoder) {
- FunctionType type = element.type;
+ ResolutionFunctionType type = element.type;
encoder.setType(Key.RETURN_TYPE, type.returnType);
encoder.setElements(Key.PARAMETERS, element.parameters);
}
@@ -420,7 +420,7 @@ class ClassSerializer implements ElementSerializer {
}
if (element.isObject) return;
- List<InterfaceType> mixins = <InterfaceType>[];
+ List<ResolutionInterfaceType> mixins = <ResolutionInterfaceType>[];
ClassElement superclass = element.superclass;
while (superclass.isUnnamedMixinApplication) {
MixinApplicationElement mixinElement = superclass;
@@ -428,12 +428,13 @@ class ClassSerializer implements ElementSerializer {
superclass = mixinElement.superclass;
}
mixins = mixins.reversed.toList();
- InterfaceType supertype = element.thisType.asInstanceOf(superclass);
+ ResolutionInterfaceType supertype =
+ element.thisType.asInstanceOf(superclass);
encoder.setType(Key.SUPERTYPE, supertype);
encoder.setTypes(Key.MIXINS, mixins);
encoder.setTypes(Key.INTERFACES, element.interfaces.toList());
- FunctionType callType = element.declaration.callType;
+ ResolutionFunctionType callType = element.declaration.callType;
if (callType != null) {
encoder.setType(Key.CALL_TYPE, element.callType);
}
@@ -848,8 +849,8 @@ class ElementDeserializer {
///
/// The class is called from the [Deserializer] when an [Element]
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
/// [DartType], and [ConstantExpression] that the deserialized [Element]
/// depends upon are available.
static Element deserialize(
ObjectDecoder decoder, SerializedElementKind elementKind) {
switch (elementKind) {
@@ -71,9 +71,9 @@ enum SerializedElementKind {
///
/// This class is called from the [Serializer] when an [Element] needs
-/// serialization. The [ObjectEncoder] ensures that any [Element], [DartType],
-/// and [ConstantExpression] that the serialized [Element] depends upon are also
-/// serialized.
+/// serialization. The [ObjectEncoder] ensures that any [Element],
+/// [ResolutionDartType], and [ConstantExpression] that the serialized [Element]
+/// depends upon are also serialized.
const List<ElementSerializer> ELEMENT_SERIALIZERS = const [
const ErrorSerializer(),
@@ -848,8 +849,8 @@ class ElementDeserializer {
/// The class is called from the [Deserializer] when an [Element]
/// needs deserialization. The [ObjectDecoder] ensures that any [Element],
- /// [DartType], and [ConstantExpression] that the deserialized [Element]
- /// depends upon are available.
+ /// [ResolutionDartType], and [ConstantExpression] that the deserialized
+ /// [Element] depends upon are available.
static Element deserialize(
ObjectDecoder decoder, SerializedElementKind elementKind) {
« no previous file with comments | « pkg/compiler/lib/src/serialization/constant_serialization.dart ('k') | pkg/compiler/lib/src/serialization/equivalence.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698